@@ -1,4 +1,14 @@
 map = [
+    {
+        "to_v":35,
+        "iso2_code":None,
+        "from_h":0,
+        "gaul_label":None,
+        "gaul_code":"0",
+        "iso3_code":None,
+        "from_v":0,
+        "to_h":35
+    },
     {
         "to_v":4,
         "iso2_code":"CA",
